#[non_exhaustive]pub enum TaskError {
Join(JoinError),
Io(Error),
Packet(PacketError),
UnknownId(u32),
ExistingId(u32),
WrongPacketKind(&'static str),
IncorrectSignature,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Join(JoinError)
Available on crate feature
connection only.Io(Error)
Packet(PacketError)
Reading a packet failed
UnknownId(u32)
gets returned if a packet with an id was received which is unknown This means a hard error and the connection should be closed
ExistingId(u32)
WrongPacketKind(&'static str)
IncorrectSignature
Available on crate feature
encrypted only.Incorrect signature