pub struct ResponseSender<P> { /* private fields */ }
A sender used to respond to a request.

Implementations

Sends the packet as a response, adding the correct flags.

If this returns an Error it either means the connection was closed or the requestor does not care about the response anymore.