pub struct Stream<P> { /* private fields */ }
A stream of packets which is inside of a connection.
If none is returned this can mean that the connection
was closed or the other side is finished sending.
Marks the stream as closed but allows to received the remaining
messages.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.