pub struct ResponseSender<P> { /* private fields */ }
A sender used to respond to a request.
Sends the packet as a response, adding the correct flags.
If this returns an Error it either means the connection was closed
or the requestor does not care about the response anymore.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.